@@ -198,6 +198,13 @@ void                  gst_rtsp_media_factory_set_retransmission_time (GstRTSPMed
 GST_RTSP_SERVER_API
 GstClockTime          gst_rtsp_media_factory_get_retransmission_time (GstRTSPMediaFactory * factory);
 
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_factory_set_do_retransmission (GstRTSPMediaFactory * factory,
+                                                                    gboolean do_retransmission);
+
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_factory_get_do_retransmission (GstRTSPMediaFactory * factory);
+
 GST_RTSP_SERVER_API
 void                  gst_rtsp_media_factory_set_latency      (GstRTSPMediaFactory * factory,
                                                                guint                 latency);
@@ -232,6 +239,19 @@ void                    gst_rtsp_media_factory_set_publish_clock_mode (GstRTSPMe
 GST_RTSP_SERVER_API
 GstRTSPPublishClockMode gst_rtsp_media_factory_get_publish_clock_mode (GstRTSPMediaFactory * factory);
 
+GST_RTSP_SERVER_API
+gboolean                gst_rtsp_media_factory_set_max_mcast_ttl (GstRTSPMediaFactory * factory,
+                                                                  guint                 ttl);
+
+GST_RTSP_SERVER_API
+guint                 gst_rtsp_media_factory_get_max_mcast_ttl (GstRTSPMediaFactory * factory);
+
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_factory_set_bind_mcast_address (GstRTSPMediaFactory * factory,
+                                                                     gboolean bind_mcast_addr);
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_factory_is_bind_mcast_address (GstRTSPMediaFactory * factory);
+
 /* creating the media from the factory and a url */
 
 GST_RTSP_SERVER_API
