@@ -281,6 +281,13 @@ void                  gst_rtsp_media_set_retransmission_time  (GstRTSPMedia *med
 GST_RTSP_SERVER_API
 GstClockTime          gst_rtsp_media_get_retransmission_time  (GstRTSPMedia *media);
 
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_set_do_retransmission (GstRTSPMedia * media,
+                                                            gboolean do_retransmission);
+
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_get_do_retransmission (GstRTSPMedia * media);
+
 GST_RTSP_SERVER_API
 void                  gst_rtsp_media_set_latency      (GstRTSPMedia *media, guint latency);
 
@@ -307,6 +314,17 @@ void                    gst_rtsp_media_set_publish_clock_mode (GstRTSPMedia * me
 GST_RTSP_SERVER_API
 GstRTSPPublishClockMode gst_rtsp_media_get_publish_clock_mode (GstRTSPMedia * media);
 
+GST_RTSP_SERVER_API
+gboolean                gst_rtsp_media_set_max_mcast_ttl  (GstRTSPMedia *media, guint ttl);
+
+GST_RTSP_SERVER_API
+guint                 gst_rtsp_media_get_max_mcast_ttl  (GstRTSPMedia *media);
+
+GST_RTSP_SERVER_API
+void                  gst_rtsp_media_set_bind_mcast_address  (GstRTSPMedia *media, gboolean bind_mcast_addr);
+GST_RTSP_SERVER_API
+gboolean              gst_rtsp_media_is_bind_mcast_address  (GstRTSPMedia *media);
+
 /* prepare the media for playback */
 
 GST_RTSP_SERVER_API
