@@ -42,14 +42,14 @@
  *
  * Last reviewed on 2013-07-11 (1.0.0)
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <string.h>
 
 #include "rtsp-session.h"
 
-#define GST_RTSP_SESSION_GET_PRIVATE(obj)  \
-       (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GST_TYPE_RTSP_SESSION, GstRTSPSessionPrivate))
-
 struct _GstRTSPSessionPrivate
 {
   GMutex lock;                  /* protects everything but sessionid and create_time */
@@ -90,15 +90,13 @@ static void gst_rtsp_session_set_property (GObject * object, guint propid,
     const GValue * value, GParamSpec * pspec);
 static void gst_rtsp_session_finalize (GObject * obj);
 
-G_DEFINE_TYPE (GstRTSPSession, gst_rtsp_session, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (GstRTSPSession, gst_rtsp_session, G_TYPE_OBJECT);
 
 static void
 gst_rtsp_session_class_init (GstRTSPSessionClass * klass)
 {
   GObjectClass *gobject_class;
 
-  g_type_class_add_private (klass, sizeof (GstRTSPSessionPrivate));
-
   gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->get_property = gst_rtsp_session_get_property;
@@ -127,9 +125,9 @@ gst_rtsp_session_class_init (GstRTSPSessionClass * klass)
 static void
 gst_rtsp_session_init (GstRTSPSession * session)
 {
-  GstRTSPSessionPrivate *priv = GST_RTSP_SESSION_GET_PRIVATE (session);
+  GstRTSPSessionPrivate *priv;
 
-  session->priv = priv;
+  session->priv = priv = gst_rtsp_session_get_instance_private (session);
 
   GST_INFO ("init session %p", session);
 
