@@ -46,6 +46,9 @@
  *
  * Last reviewed on 2013-07-11 (1.0.0)
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include <string.h>
 
@@ -57,6 +60,8 @@ typedef struct _GstRTSPThreadImpl
 
   gint reused;
   GSource *source;
+  /* FIXME, the source has to be part of GstRTSPThreadImpl, due to a bug in GLib:
+   * https://bugzilla.gnome.org/show_bug.cgi?id=720186 */
 } GstRTSPThreadImpl;
 
 GST_DEFINE_MINI_OBJECT_TYPE (GstRTSPThread, gst_rtsp_thread);
@@ -182,9 +187,6 @@ gst_rtsp_thread_stop (GstRTSPThread * thread)
     gst_rtsp_thread_unref (thread);
 }
 
-#define GST_RTSP_THREAD_POOL_GET_PRIVATE(obj)  \
-   (G_TYPE_INSTANCE_GET_PRIVATE ((obj), GST_TYPE_RTSP_THREAD_POOL, GstRTSPThreadPoolPrivate))
-
 struct _GstRTSPThreadPoolPrivate
 {
   GMutex lock;
@@ -218,15 +220,14 @@ static gpointer do_loop (GstRTSPThread * thread);
 static GstRTSPThread *default_get_thread (GstRTSPThreadPool * pool,
     GstRTSPThreadType type, GstRTSPContext * ctx);
 
-G_DEFINE_TYPE (GstRTSPThreadPool, gst_rtsp_thread_pool, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (GstRTSPThreadPool, gst_rtsp_thread_pool,
+    G_TYPE_OBJECT);
 
 static void
 gst_rtsp_thread_pool_class_init (GstRTSPThreadPoolClass * klass)
 {
   GObjectClass *gobject_class;
 
-  g_type_class_add_private (klass, sizeof (GstRTSPThreadPoolPrivate));
-
   gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->get_property = gst_rtsp_thread_pool_get_property;
@@ -259,7 +260,7 @@ gst_rtsp_thread_pool_init (GstRTSPThreadPool * pool)
 {
   GstRTSPThreadPoolPrivate *priv;
 
-  pool->priv = priv = GST_RTSP_THREAD_POOL_GET_PRIVATE (pool);
+  pool->priv = priv = gst_rtsp_thread_pool_get_instance_private (pool);
 
   g_mutex_init (&priv->lock);
   priv->max_threads = DEFAULT_MAX_THREADS;
@@ -510,7 +511,8 @@ thread_error:
  *
  * Get a new #GstRTSPThread for @type and @ctx.
  *
- * Returns: (transfer full): a new #GstRTSPThread, gst_rtsp_thread_stop() after usage
+ * Returns: (transfer full) (nullable): a new #GstRTSPThread,
+ * gst_rtsp_thread_stop() after usage
  */
 GstRTSPThread *
 gst_rtsp_thread_pool_get_thread (GstRTSPThreadPool * pool,
